#!/usr/bin/perl -w
#Filename:
#Author: Tian Dongmei
#Email: tiandm@big.ac.cn
#Date: 2013/7/19
#Modified:
#Description: 
my $version=1.00;

use strict;
use Getopt::Long;
use File::Basename;

my %opts;
GetOptions(\%opts,"i=s","o=s","tag:s","h");
if (!(defined $opts{i} and defined $opts{o} ) || defined $opts{h}) { #necessary arguments
&usage;
}

my $filein=$opts{'i'};
my $fileout=$opts{'o'};

my $marks=defined $opts{'tag'} ? $opts{'tag'} : "";

if(!(defined $opts{'tag'})){
	my $line=`head -1 $filein`;
	my @tmp=split/\t/,$line;
	$tmp[0]=~/:([\d|_]+)_x(\d+)$/;
	my @ss=split/_/,$1;
	for (my $i=1;$i<=@ss;$i++) {
		$marks .="Smp$i;";
	}
}

my @marks=split/\;/,$marks;

my %rfam_key;
while(<DATA>){
    chomp;
    if(/^(\S+)\s+(\S+)$/){
		$rfam_key{$1}=$2;
    }
}


my %reads;
my %tags;
open IN,"<$filein";
while (my $aline=<IN>) {
	chomp $aline;
	my @tmp=split/\t/,$aline;
	$tmp[0]=~/:([\d|_]+)_x(\d+)$/;

	my @exp=split/_/,$1;
	my @tag=split/\;/,$tmp[2];

	if (defined $rfam_key{$tag[0]}) {
		for (my $i=0;$i<@exp;$i++) {
			$reads{$rfam_key{$tag[0]}}[$i]+=$exp[$i];
			$tags{$rfam_key{$tag[0]}}[$i]++ if($exp[$i]!=0);
		}
	}else{
		for (my $i=0;$i<@exp;$i++) {
			$reads{other}[$i]+=$exp[$i];
			$tags{other}[$i]++ if($exp[$i]!=0);
		}
	}

}
close IN;

$"="\t"; ##### @array print in \t
open OUT,">$fileout";
print OUT "####################################\n# small RNA expressed reads number #\n####################################\n";
print OUT "#RNAname\t@marks\n";
foreach my $key (keys %reads) {
	print OUT $key;
	for (my $i=0;$i<@{$reads{$key}} ;$i++) {
		print OUT "\t",$reads{$key}[$i];
	}
	print OUT "\n";
}

print OUT "\n\n####################################\n# small RNA expressed tags number #\n####################################\n";
print OUT "#RNAname\t@marks\n";

foreach my $key (keys %tags) {
	print OUT  $key;
	for (my $i=0;$i<@{$reads{$key}} ;$i++) {
		if(defined $tags{$key}[$i]){print OUT "\t",$tags{$key}[$i];}
		else{print OUT "\t0";}
	}
	print OUT  "\n";
}

close OUT;
$"=" "; ##### @array print in \t

sub usage{
print <<"USAGE";
Version $version
Usage:
$0 -i -tag -o
options:
-i input file# rfam bowtie bwt. format mapping result
-tag [string] sample marks# eg. sampleA;sampleB;sampleC
-o output file

-h help
USAGE
exit(1);
}

__DATA__
RF00635	lncRNA
RF01868	lncRNA
RF01869	lncRNA
RF01870	lncRNA
RF01871	lncRNA
RF01872	lncRNA
RF01873	lncRNA
RF01874	lncRNA
RF01875	lncRNA
RF01876	lncRNA
RF01877	lncRNA
RF01878	lncRNA
RF01879	lncRNA
RF01880	lncRNA
RF01881	lncRNA
RF01882	lncRNA
RF01883	lncRNA
RF01884	lncRNA
RF01885	lncRNA
RF01886	lncRNA
RF01887	lncRNA
RF01888	lncRNA
RF01889	lncRNA
RF01890	lncRNA
RF01891	lncRNA
RF01892	lncRNA
RF01893	lncRNA
RF01894	lncRNA
RF01904	lncRNA
RF01905	lncRNA
RF01906	lncRNA
RF01907	lncRNA
RF01908	lncRNA
RF01909	lncRNA
RF01928	lncRNA
RF01929	lncRNA
RF01930	lncRNA
RF01931	lncRNA
RF01932	lncRNA
RF01933	lncRNA
RF01934	lncRNA
RF01935	lncRNA
RF01946	lncRNA
RF01947	lncRNA
RF01948	lncRNA
RF01950	lncRNA
RF01951	lncRNA
RF01952	lncRNA
RF01953	lncRNA
RF01954	lncRNA
RF01955	lncRNA
RF01956	lncRNA
RF01957	lncRNA
RF01958	lncRNA
RF01961	lncRNA
RF01962	lncRNA
RF01963	lncRNA
RF01964	lncRNA
RF01965	lncRNA
RF01966	lncRNA
RF01967	lncRNA
RF01968	lncRNA
RF01969	lncRNA
RF01970	lncRNA
RF01971	lncRNA
RF01972	lncRNA
RF01973	lncRNA
RF01974	lncRNA
RF01975	lncRNA
RF01976	lncRNA
RF01977	lncRNA
RF01978	lncRNA
RF01979	lncRNA
RF01980	lncRNA
RF01981	lncRNA
RF01983	lncRNA
RF01984	lncRNA
RF01985	lncRNA
RF01986	lncRNA
RF01987	lncRNA
RF01992	lncRNA
RF02038	lncRNA
RF02039	lncRNA
RF02040	lncRNA
RF02041	lncRNA
RF02042	lncRNA
RF02043	lncRNA
RF02044	lncRNA
RF02045	lncRNA
RF02046	lncRNA
RF02047	lncRNA
RF02085	lncRNA
RF02086	lncRNA
RF02087	lncRNA
RF02089	lncRNA
RF02090	lncRNA
RF02091	lncRNA
RF02098	lncRNA
RF02101	lncRNA
RF02102	lncRNA
RF02103	lncRNA
RF02104	lncRNA
RF02105	lncRNA
RF02106	lncRNA
RF02107	lncRNA
RF02108	lncRNA
RF02109	lncRNA
RF02110	lncRNA
RF02112	lncRNA
RF02113	lncRNA
RF02114	lncRNA
RF02115	lncRNA
RF02116	lncRNA
RF02117	lncRNA
RF02118	lncRNA
RF02119	lncRNA
RF02120	lncRNA
RF02121	lncRNA
RF02122	lncRNA
RF02123	lncRNA
RF02124	lncRNA
RF02125	lncRNA
RF02126	lncRNA
RF02127	lncRNA
RF02128	lncRNA
RF02129	lncRNA
RF02130	lncRNA
RF02131	lncRNA
RF02132	lncRNA
RF02133	lncRNA
RF02134	lncRNA
RF02135	lncRNA
RF02136	lncRNA
RF02137	lncRNA
RF02138	lncRNA
RF02139	lncRNA
RF02140	lncRNA
RF02141	lncRNA
RF02142	lncRNA
RF02143	lncRNA
RF02145	lncRNA
RF02146	lncRNA
RF02147	lncRNA
RF02148	lncRNA
RF02149	lncRNA
RF02150	lncRNA
RF02152	lncRNA
RF02153	lncRNA
RF02154	lncRNA
RF02155	lncRNA
RF02156	lncRNA
RF02157	lncRNA
RF02158	lncRNA
RF02159	lncRNA
RF02160	lncRNA
RF02161	lncRNA
RF02164	lncRNA
RF02165	lncRNA
RF02166	lncRNA
RF02167	lncRNA
RF02168	lncRNA
RF02169	lncRNA
RF02170	lncRNA
RF02171	lncRNA
RF02172	lncRNA
RF02173	lncRNA
RF02174	lncRNA
RF02175	lncRNA
RF02176	lncRNA
RF02177	lncRNA
RF02178	lncRNA
RF02179	lncRNA
RF02180	lncRNA
RF02181	lncRNA
RF02182	lncRNA
RF02183	lncRNA
RF02184	lncRNA
RF02185	lncRNA
RF02186	lncRNA
RF02187	lncRNA
RF02188	lncRNA
RF02189	lncRNA
RF02190	lncRNA
RF02191	lncRNA
RF02192	lncRNA
RF02193	lncRNA
RF02195	lncRNA
RF02196	lncRNA
RF02197	lncRNA
RF02198	lncRNA
RF02199	lncRNA
RF02200	lncRNA
RF02201	lncRNA
RF02202	lncRNA
RF02203	lncRNA
RF02204	lncRNA
RF02205	lncRNA
RF02206	lncRNA
RF02207	lncRNA
RF02208	lncRNA
RF02209	lncRNA
RF02210	lncRNA
RF02211	lncRNA
RF02212	lncRNA
RF02213	lncRNA
RF02215	lncRNA
RF02216	lncRNA
RF02217	lncRNA
RF02218	lncRNA
RF02219	lncRNA
RF02220	lncRNA
RF02246	lncRNA
RF02247	lncRNA
RF02248	lncRNA
RF02249	lncRNA
RF02250	lncRNA
RF02251	lncRNA
RF02252	lncRNA
RF02255	lncRNA
RF02256	lncRNA
RF02257	lncRNA
RF02258	lncRNA
RF02259	lncRNA
RF02267	lncRNA
RF02272	lncRNA
RF00027	miRNA
RF00047	miRNA
RF00051	miRNA
RF00052	miRNA
RF00053	miRNA
RF00073	miRNA
RF00074	miRNA
RF00075	miRNA
RF00076	miRNA
RF00103	miRNA
RF00104	miRNA
RF00129	miRNA
RF00130	miRNA
RF00131	miRNA
RF00143	miRNA
RF00144	miRNA
RF00178	miRNA
RF00237	miRNA
RF00239	miRNA
RF00241	miRNA
RF00244	miRNA
RF00245	miRNA
RF00246	miRNA
RF00247	miRNA
RF00248	miRNA
RF00249	miRNA
RF00250	miRNA
RF00251	miRNA
RF00253	miRNA
RF00254	miRNA
RF00255	miRNA
RF00256	miRNA
RF00257	miRNA
RF00258	miRNA
RF00363	miRNA
RF00364	miRNA
RF00365	miRNA
RF00366	miRNA
RF00367	miRNA
RF00445	miRNA
RF00446	miRNA
RF00451	miRNA
RF00452	miRNA
RF00455	miRNA
RF00456	miRNA
RF00464	miRNA
RF00486	miRNA
RF00637	miRNA
RF00638	miRNA
RF00639	miRNA
RF00640	miRNA
RF00641	miRNA
RF00642	miRNA
RF00643	miRNA
RF00644	miRNA
RF00645	miRNA
RF00646	miRNA
RF00647	miRNA
RF00648	miRNA
RF00649	miRNA
RF00650	miRNA
RF00651	miRNA
RF00652	miRNA
RF00653	miRNA
RF00654	miRNA
RF00655	miRNA
RF00656	miRNA
RF00657	miRNA
RF00658	miRNA
RF00659	miRNA
RF00660	miRNA
RF00661	miRNA
RF00662	miRNA
RF00663	miRNA
RF00664	miRNA
RF00665	miRNA
RF00666	miRNA
RF00667	miRNA
RF00668	miRNA
RF00669	miRNA
RF00670	miRNA
RF00671	miRNA
RF00672	miRNA
RF00673	miRNA
RF00674	miRNA
RF00675	miRNA
RF00676	miRNA
RF00677	miRNA
RF00678	miRNA
RF00679	miRNA
RF00680	miRNA
RF00681	miRNA
RF00682	miRNA
RF00683	miRNA
RF00684	miRNA
RF00685	miRNA
RF00686	miRNA
RF00687	miRNA
RF00688	miRNA
RF00689	miRNA
RF00690	miRNA
RF00691	miRNA
RF00692	miRNA
RF00693	miRNA
RF00694	miRNA
RF00695	miRNA
RF00696	miRNA
RF00697	miRNA
RF00698	miRNA
RF00699	miRNA
RF00700	miRNA
RF00701	miRNA
RF00702	miRNA
RF00703	miRNA
RF00704	miRNA
RF00705	miRNA
RF00706	miRNA
RF00707	miRNA
RF00708	miRNA
RF00709	miRNA
RF00710	miRNA
RF00711	miRNA
RF00712	miRNA
RF00713	miRNA
RF00714	miRNA
RF00715	miRNA
RF00716	miRNA
RF00717	miRNA
RF00718	miRNA
RF00719	miRNA
RF00720	miRNA
RF00721	miRNA
RF00722	miRNA
RF00723	miRNA
RF00724	miRNA
RF00725	miRNA
RF00726	miRNA
RF00727	miRNA
RF00728	miRNA
RF00729	miRNA
RF00730	miRNA
RF00731	miRNA
RF00732	miRNA
RF00733	miRNA
RF00734	miRNA
RF00735	miRNA
RF00736	miRNA
RF00737	miRNA
RF00739	miRNA
RF00740	miRNA
RF00741	miRNA
RF00742	miRNA
RF00743	miRNA
RF00744	miRNA
RF00745	miRNA
RF00746	miRNA
RF00747	miRNA
RF00748	miRNA
RF00749	miRNA
RF00750	miRNA
RF00751	miRNA
RF00752	miRNA
RF00753	miRNA
RF00754	miRNA
RF00755	miRNA
RF00756	miRNA
RF00757	miRNA
RF00758	miRNA
RF00760	miRNA
RF00761	miRNA
RF00762	miRNA
RF00763	miRNA
RF00764	miRNA
RF00765	miRNA
RF00766	miRNA
RF00767	miRNA
RF00768	miRNA
RF00769	miRNA
RF00770	miRNA
RF00771	miRNA
RF00772	miRNA
RF00773	miRNA
RF00774	miRNA
RF00775	miRNA
RF00776	miRNA
RF00777	miRNA
RF00778	miRNA
RF00779	miRNA
RF00780	miRNA
RF00781	miRNA
RF00782	miRNA
RF00783	miRNA
RF00784	miRNA
RF00785	miRNA
RF00786	miRNA
RF00787	miRNA
RF00788	miRNA
RF00789	miRNA
RF00790	miRNA
RF00791	miRNA
RF00792	miRNA
RF00793	miRNA
RF00794	miRNA
RF00795	miRNA
RF00796	miRNA
RF00797	miRNA
RF00798	miRNA
RF00799	miRNA
RF00800	miRNA
RF00801	miRNA
RF00802	miRNA
RF00803	miRNA
RF00804	miRNA
RF00805	miRNA
RF00806	miRNA
RF00807	miRNA
RF00808	miRNA
RF00809	miRNA
RF00810	miRNA
RF00811	miRNA
RF00812	miRNA
RF00813	miRNA
RF00814	miRNA
RF00815	miRNA
RF00816	miRNA
RF00817	miRNA
RF00818	miRNA
RF00819	miRNA
RF00820	miRNA
RF00821	miRNA
RF00822	miRNA
RF00823	miRNA
RF00824	miRNA
RF00825	miRNA
RF00826	miRNA
RF00827	miRNA
RF00828	miRNA
RF00829	miRNA
RF00830	miRNA
RF00831	miRNA
RF00832	miRNA
RF00833	miRNA
RF00834	miRNA
RF00835	miRNA
RF00836	miRNA
RF00837	miRNA
RF00838	miRNA
RF00839	miRNA
RF00840	miRNA
RF00841	miRNA
RF00842	miRNA
RF00843	miRNA
RF00844	miRNA
RF00845	miRNA
RF00846	miRNA
RF00847	miRNA
RF00848	miRNA
RF00849	miRNA
RF00850	miRNA
RF00851	miRNA
RF00852	miRNA
RF00853	miRNA
RF00854	miRNA
RF00855	miRNA
RF00856	miRNA
RF00857	miRNA
RF00858	miRNA
RF00859	miRNA
RF00861	miRNA
RF00862	miRNA
RF00863	miRNA
RF00864	miRNA
RF00865	miRNA
RF00866	miRNA
RF00867	miRNA
RF00868	miRNA
RF00869	miRNA
RF00870	miRNA
RF00871	miRNA
RF00872	miRNA
RF00873	miRNA
RF00874	miRNA
RF00875	miRNA
RF00876	miRNA
RF00877	miRNA
RF00878	miRNA
RF00879	miRNA
RF00882	miRNA
RF00883	miRNA
RF00884	miRNA
RF00885	miRNA
RF00886	miRNA
RF00887	miRNA
RF00888	miRNA
RF00890	miRNA
RF00891	miRNA
RF00892	miRNA
RF00893	miRNA
RF00894	miRNA
RF00895	miRNA
RF00896	miRNA
RF00897	miRNA
RF00898	miRNA
RF00899	miRNA
RF00900	miRNA
RF00901	miRNA
RF00902	miRNA
RF00903	miRNA
RF00904	miRNA
RF00905	miRNA
RF00906	miRNA
RF00907	miRNA
RF00908	miRNA
RF00909	miRNA
RF00910	miRNA
RF00911	miRNA
RF00912	miRNA
RF00914	miRNA
RF00915	miRNA
RF00917	miRNA
RF00918	miRNA
RF00919	miRNA
RF00920	miRNA
RF00921	miRNA
RF00922	miRNA
RF00925	miRNA
RF00926	miRNA
RF00927	miRNA
RF00928	miRNA
RF00929	miRNA
RF00931	miRNA
RF00932	miRNA
RF00933	miRNA
RF00934	miRNA
RF00935	miRNA
RF00936	miRNA
RF00937	miRNA
RF00939	miRNA
RF00940	miRNA
RF00941	miRNA
RF00942	miRNA
RF00943	miRNA
RF00945	miRNA
RF00946	miRNA
RF00947	miRNA
RF00948	miRNA
RF00949	miRNA
RF00950	miRNA
RF00951	miRNA
RF00952	miRNA
RF00953	miRNA
RF00954	miRNA
RF00955	miRNA
RF00956	miRNA
RF00957	miRNA
RF00958	miRNA
RF00959	miRNA
RF00960	miRNA
RF00961	miRNA
RF00962	miRNA
RF00963	miRNA
RF00964	miRNA
RF00965	miRNA
RF00966	miRNA
RF00967	miRNA
RF00968	miRNA
RF00969	miRNA
RF00970	miRNA
RF00971	miRNA
RF00972	miRNA
RF00973	miRNA
RF00974	miRNA
RF00975	miRNA
RF00976	miRNA
RF00977	miRNA
RF00978	miRNA
RF00979	miRNA
RF00980	miRNA
RF00981	miRNA
RF00983	miRNA
RF00984	miRNA
RF00985	miRNA
RF00986	miRNA
RF00987	miRNA
RF00988	miRNA
RF00989	miRNA
RF00990	miRNA
RF00991	miRNA
RF00992	miRNA
RF00993	miRNA
RF00994	miRNA
RF00995	miRNA
RF00996	miRNA
RF00997	miRNA
RF00998	miRNA
RF00999	miRNA
RF01000	miRNA
RF01001	miRNA
RF01002	miRNA
RF01003	miRNA
RF01004	miRNA
RF01005	miRNA
RF01006	miRNA
RF01007	miRNA
RF01008	miRNA
RF01009	miRNA
RF01010	miRNA
RF01011	miRNA
RF01012	miRNA
RF01013	miRNA
RF01014	miRNA
RF01015	miRNA
RF01016	miRNA
RF01017	miRNA
RF01018	miRNA
RF01019	miRNA
RF01020	miRNA
RF01021	miRNA
RF01022	miRNA
RF01023	miRNA
RF01024	miRNA
RF01025	miRNA
RF01026	miRNA
RF01027	miRNA
RF01028	miRNA
RF01029	miRNA
RF01030	miRNA
RF01031	miRNA
RF01032	miRNA
RF01033	miRNA
RF01034	miRNA
RF01035	miRNA
RF01036	miRNA
RF01037	miRNA
RF01038	miRNA
RF01039	miRNA
RF01040	miRNA
RF01041	miRNA
RF01042	miRNA
RF01043	miRNA
RF01044	miRNA
RF01045	miRNA
RF01059	miRNA
RF01061	miRNA
RF01063	miRNA
RF01064	miRNA
RF01117	miRNA
RF01314	miRNA
RF01413	miRNA
RF01895	miRNA
RF01896	miRNA
RF01897	miRNA
RF01898	miRNA
RF01899	miRNA
RF01900	miRNA
RF01901	miRNA
RF01902	miRNA
RF01903	miRNA
RF01910	miRNA
RF01911	miRNA
RF01912	miRNA
RF01913	miRNA
RF01914	miRNA
RF01915	miRNA
RF01916	miRNA
RF01917	miRNA
RF01918	miRNA
RF01919	miRNA
RF01920	miRNA
RF01921	miRNA
RF01922	miRNA
RF01923	miRNA
RF01924	miRNA
RF01925	miRNA
RF01926	miRNA
RF01927	miRNA
RF01936	miRNA
RF01937	miRNA
RF01938	miRNA
RF01939	miRNA
RF01940	miRNA
RF01941	miRNA
RF01942	miRNA
RF01943	miRNA
RF01944	miRNA
RF01945	miRNA
RF01996	miRNA
RF01997	miRNA
RF02000	miRNA
RF02002	miRNA
RF02006	miRNA
RF02007	miRNA
RF02008	miRNA
RF02009	miRNA
RF02010	miRNA
RF02011	miRNA
RF02013	miRNA
RF02014	miRNA
RF02015	miRNA
RF02016	miRNA
RF02017	miRNA
RF02018	miRNA
RF02019	miRNA
RF02020	miRNA
RF02021	miRNA
RF02022	miRNA
RF02023	miRNA
RF02024	miRNA
RF02025	miRNA
RF02026	miRNA
RF02027	miRNA
RF02028	miRNA
RF02061	miRNA
RF02092	miRNA
RF02093	miRNA
RF02094	miRNA
RF02095	miRNA
RF02096	miRNA
RF02097	miRNA
RF02214	miRNA
RF02244	miRNA
RF02245	miRNA
RF02254	miRNA
RF00001	rRNA
RF00002	rRNA
RF01118	rRNA
RF01960	rRNA
RF00177	rRNA
RF01959	rRNA
RF00003	snRNA
RF00004	snRNA
RF00007	snRNA
RF00012	snRNA
RF00015	snRNA
RF00016	snRNA
RF00020	snRNA
RF00026	snRNA
RF00045	snRNA
RF00046	snRNA
RF00049	snRNA
RF00054	snRNA
RF00055	snRNA
RF00056	snRNA
RF00065	snRNA
RF00066	snRNA
RF00067	snRNA
RF00068	snRNA
RF00069	snRNA
RF00070	snRNA
RF00071	snRNA
RF00072	snRNA
RF00085	snRNA
RF00086	snRNA
RF00087	snRNA
RF00088	snRNA
RF00089	snRNA
RF00090	snRNA
RF00091	snRNA
RF00092	snRNA
RF00093	snRNA
RF00095	snRNA
RF00096	snRNA
RF00097	snRNA
RF00099	snRNA
RF00105	snRNA
RF00108	snRNA
RF00132	snRNA
RF00133	snRNA
RF00134	snRNA
RF00135	snRNA
RF00136	snRNA
RF00137	snRNA
RF00138	snRNA
RF00139	snRNA
RF00142	snRNA
RF00145	snRNA
RF00147	snRNA
RF00149	snRNA
RF00150	snRNA
RF00151	snRNA
RF00152	snRNA
RF00153	snRNA
RF00154	snRNA
RF00155	snRNA
RF00156	snRNA
RF00157	snRNA
RF00158	snRNA
RF00159	snRNA
RF00160	snRNA
RF00181	snRNA
RF00186	snRNA
RF00187	snRNA
RF00188	snRNA
RF00189	snRNA
RF00190	snRNA
RF00191	snRNA
RF00200	snRNA
RF00201	snRNA
RF00202	snRNA
RF00203	snRNA
RF00204	snRNA
RF00205	snRNA
RF00206	snRNA
RF00208	snRNA
RF00211	snRNA
RF00212	snRNA
RF00213	snRNA
RF00217	snRNA
RF00218	snRNA
RF00221	snRNA
RF00231	snRNA
RF00263	snRNA
RF00264	snRNA
RF00265	snRNA
RF00266	snRNA
RF00267	snRNA
RF00268	snRNA
RF00270	snRNA
RF00271	snRNA
RF00272	snRNA
RF00273	snRNA
RF00274	snRNA
RF00275	snRNA
RF00276	snRNA
RF00277	snRNA
RF00278	snRNA
RF00279	snRNA
RF00280	snRNA
RF00281	snRNA
RF00282	snRNA
RF00283	snRNA
RF00284	snRNA
RF00285	snRNA
RF00286	snRNA
RF00287	snRNA
RF00288	snRNA
RF00289	snRNA
RF00291	snRNA
RF00292	snRNA
RF00293	snRNA
RF00294	snRNA
RF00295	snRNA
RF00296	snRNA
RF00300	snRNA
RF00301	snRNA
RF00302	snRNA
RF00303	snRNA
RF00304	snRNA
RF00305	snRNA
RF00306	snRNA
RF00307	snRNA
RF00309	snRNA
RF00310	snRNA
RF00311	snRNA
RF00312	snRNA
RF00313	snRNA
RF00314	snRNA
RF00315	snRNA
RF00316	snRNA
RF00317	snRNA
RF00318	snRNA
RF00319	snRNA
RF00320	snRNA
RF00321	snRNA
RF00322	snRNA
RF00323	snRNA
RF00324	snRNA
RF00325	snRNA
RF00326	snRNA
RF00327	snRNA
RF00328	snRNA
RF00329	snRNA
RF00330	snRNA
RF00331	snRNA
RF00332	snRNA
RF00333	snRNA
RF00334	snRNA
RF00335	snRNA
RF00336	snRNA
RF00337	snRNA
RF00338	snRNA
RF00339	snRNA
RF00340	snRNA
RF00341	snRNA
RF00342	snRNA
RF00343	snRNA
RF00344	snRNA
RF00345	snRNA
RF00348	snRNA
RF00349	snRNA
RF00350	snRNA
RF00351	snRNA
RF00352	snRNA
RF00353	snRNA
RF00355	snRNA
RF00356	snRNA
RF00357	snRNA
RF00358	snRNA
RF00359	snRNA
RF00360	snRNA
RF00361	snRNA
RF00377	snRNA
RF00392	snRNA
RF00393	snRNA
RF00394	snRNA
RF00396	snRNA
RF00397	snRNA
RF00398	snRNA
RF00399	snRNA
RF00400	snRNA
RF00401	snRNA
RF00402	snRNA
RF00403	snRNA
RF00404	snRNA
RF00405	snRNA
RF00406	snRNA
RF00407	snRNA
RF00408	snRNA
RF00409	snRNA
RF00410	snRNA
RF00411	snRNA
RF00412	snRNA
RF00413	snRNA
RF00414	snRNA
RF00415	snRNA
RF00416	snRNA
RF00417	snRNA
RF00418	snRNA
RF00419	snRNA
RF00420	snRNA
RF00421	snRNA
RF00422	snRNA
RF00423	snRNA
RF00424	snRNA
RF00425	snRNA
RF00426	snRNA
RF00427	snRNA
RF00428	snRNA
RF00429	snRNA
RF00430	snRNA
RF00431	snRNA
RF00432	snRNA
RF00438	snRNA
RF00439	snRNA
RF00440	snRNA
RF00441	snRNA
RF00443	snRNA
RF00471	snRNA
RF00472	snRNA
RF00473	snRNA
RF00474	snRNA
RF00475	snRNA
RF00476	snRNA
RF00477	snRNA
RF00478	snRNA
RF00479	snRNA
RF00482	snRNA
RF00488	snRNA
RF00492	snRNA
RF00493	snRNA
RF00494	snRNA
RF00509	snRNA
RF00526	snRNA
RF00527	snRNA
RF00528	snRNA
RF00529	snRNA
RF00530	snRNA
RF00531	snRNA
RF00532	snRNA
RF00533	snRNA
RF00535	snRNA
RF00536	snRNA
RF00537	snRNA
RF00538	snRNA
RF00539	snRNA
RF00540	snRNA
RF00541	snRNA
RF00542	snRNA
RF00543	snRNA
RF00544	snRNA
RF00545	snRNA
RF00546	snRNA
RF00548	snRNA
RF00553	snRNA
RF00554	snRNA
RF00560	snRNA
RF00561	snRNA
RF00562	snRNA
RF00563	snRNA
RF00564	snRNA
RF00565	snRNA
RF00566	snRNA
RF00567	snRNA
RF00568	snRNA
RF00569	snRNA
RF00570	snRNA
RF00571	snRNA
RF00572	snRNA
RF00573	snRNA
RF00574	snRNA
RF00575	snRNA
RF00576	snRNA
RF00577	snRNA
RF00578	snRNA
RF00579	snRNA
RF00580	snRNA
RF00581	snRNA
RF00582	snRNA
RF00584	snRNA
RF00586	snRNA
RF00588	snRNA
RF00591	snRNA
RF00592	snRNA
RF00593	snRNA
RF00594	snRNA
RF00598	snRNA
RF00599	snRNA
RF00600	snRNA
RF00601	snRNA
RF00602	snRNA
RF00603	snRNA
RF00604	snRNA
RF00606	snRNA
RF00607	snRNA
RF00608	snRNA
RF00609	snRNA
RF00610	snRNA
RF00611	snRNA
RF00612	snRNA
RF00613	snRNA
RF00614	snRNA
RF00618	snRNA
RF00619	snRNA
RF01119	snRNA
RF01120	snRNA
RF01121	snRNA
RF01122	snRNA
RF01123	snRNA
RF01124	snRNA
RF01125	snRNA
RF01126	snRNA
RF01127	snRNA
RF01128	snRNA
RF01129	snRNA
RF01130	snRNA
RF01131	snRNA
RF01132	snRNA
RF01133	snRNA
RF01134	snRNA
RF01135	snRNA
RF01136	snRNA
RF01137	snRNA
RF01138	snRNA
RF01139	snRNA
RF01140	snRNA
RF01141	snRNA
RF01142	snRNA
RF01143	snRNA
RF01144	snRNA
RF01145	snRNA
RF01146	snRNA
RF01147	snRNA
RF01148	snRNA
RF01149	snRNA
RF01150	snRNA
RF01151	snRNA
RF01152	snRNA
RF01153	snRNA
RF01155	snRNA
RF01156	snRNA
RF01157	snRNA
RF01158	snRNA
RF01159	snRNA
RF01160	snRNA
RF01161	snRNA
RF01162	snRNA
RF01163	snRNA
RF01164	snRNA
RF01165	snRNA
RF01166	snRNA
RF01167	snRNA
RF01168	snRNA
RF01169	snRNA
RF01170	snRNA
RF01171	snRNA
RF01172	snRNA
RF01173	snRNA
RF01174	snRNA
RF01175	snRNA
RF01176	snRNA
RF01177	snRNA
RF01178	snRNA
RF01179	snRNA
RF01180	snRNA
RF01181	snRNA
RF01182	snRNA
RF01183	snRNA
RF01184	snRNA
RF01185	snRNA
RF01186	snRNA
RF01188	snRNA
RF01189	snRNA
RF01190	snRNA
RF01191	snRNA
RF01192	snRNA
RF01193	snRNA
RF01194	snRNA
RF01195	snRNA
RF01196	snRNA
RF01197	snRNA
RF01198	snRNA
RF01199	snRNA
RF01200	snRNA
RF01201	snRNA
RF01202	snRNA
RF01203	snRNA
RF01204	snRNA
RF01205	snRNA
RF01206	snRNA
RF01207	snRNA
RF01208	snRNA
RF01209	snRNA
RF01210	snRNA
RF01211	snRNA
RF01212	snRNA
RF01213	snRNA
RF01214	snRNA
RF01215	snRNA
RF01216	snRNA
RF01218	snRNA
RF01219	snRNA
RF01220	snRNA
RF01221	snRNA
RF01222	snRNA
RF01223	snRNA
RF01224	snRNA
RF01225	snRNA
RF01226	snRNA
RF01227	snRNA
RF01228	snRNA
RF01229	snRNA
RF01230	snRNA
RF01231	snRNA
RF01232	snRNA
RF01233	snRNA
RF01234	snRNA
RF01235	snRNA
RF01236	snRNA
RF01237	snRNA
RF01238	snRNA
RF01239	snRNA
RF01240	snRNA
RF01241	snRNA
RF01242	snRNA
RF01243	snRNA
RF01244	snRNA
RF01245	snRNA
RF01246	snRNA
RF01247	snRNA
RF01248	snRNA
RF01249	snRNA
RF01250	snRNA
RF01251	snRNA
RF01252	snRNA
RF01253	snRNA
RF01254	snRNA
RF01255	snRNA
RF01256	snRNA
RF01257	snRNA
RF01258	snRNA
RF01259	snRNA
RF01260	snRNA
RF01261	snRNA
RF01262	snRNA
RF01263	snRNA
RF01264	snRNA
RF01265	snRNA
RF01266	snRNA
RF01267	snRNA
RF01268	snRNA
RF01269	snRNA
RF01270	snRNA
RF01271	snRNA
RF01272	snRNA
RF01273	snRNA
RF01274	snRNA
RF01275	snRNA
RF01276	snRNA
RF01277	snRNA
RF01278	snRNA
RF01279	snRNA
RF01280	snRNA
RF01281	snRNA
RF01283	snRNA
RF01284	snRNA
RF01285	snRNA
RF01286	snRNA
RF01287	snRNA
RF01288	snRNA
RF01289	snRNA
RF01290	snRNA
RF01291	snRNA
RF01292	snRNA
RF01293	snRNA
RF01294	snRNA
RF01295	snRNA
RF01296	snRNA
RF01297	snRNA
RF01298	snRNA
RF01299	snRNA
RF01300	snRNA
RF01301	snRNA
RF01302	snRNA
RF01303	snRNA
RF01304	snRNA
RF01305	snRNA
RF01306	snRNA
RF01307	snRNA
RF01308	snRNA
RF01309	snRNA
RF01310	snRNA
RF01311	snRNA
RF01312	snRNA
RF01420	snRNA
RF01421	snRNA
RF01422	snRNA
RF01423	snRNA
RF01424	snRNA
RF01425	snRNA
RF01426	snRNA
RF01427	snRNA
RF01428	snRNA
RF01429	snRNA
RF01430	snRNA
RF01431	snRNA
RF01432	snRNA
RF01433	snRNA
RF01434	snRNA
RF01435	snRNA
RF01436	snRNA
RF01437	snRNA
RF01438	snRNA
RF01439	snRNA
RF01440	snRNA
RF01441	snRNA
RF01442	snRNA
RF01443	snRNA
RF01444	snRNA
RF01445	snRNA
RF01446	snRNA
RF01447	snRNA
RF01448	snRNA
RF01449	snRNA
RF01450	snRNA
RF01451	snRNA
RF01452	snRNA
RF01498	snRNA
RF01499	snRNA
RF01500	snRNA
RF01501	snRNA
RF01505	snRNA
RF01506	snRNA
RF01507	snRNA
RF01509	snRNA
RF01511	snRNA
RF01513	snRNA
RF01514	snRNA
RF01515	snRNA
RF01516	snRNA
RF01522	snRNA
RF01523	snRNA
RF01524	snRNA
RF01525	snRNA
RF01526	snRNA
RF01531	snRNA
RF01532	snRNA
RF01533	snRNA
RF01534	snRNA
RF01535	snRNA
RF01536	snRNA
RF01537	snRNA
RF01538	snRNA
RF01539	snRNA
RF01540	snRNA
RF01541	snRNA
RF01542	snRNA
RF01543	snRNA
RF01544	snRNA
RF01545	snRNA
RF01546	snRNA
RF01547	snRNA
RF01548	snRNA
RF01549	snRNA
RF01550	snRNA
RF01551	snRNA
RF01552	snRNA
RF01553	snRNA
RF01554	snRNA
RF01555	snRNA
RF01556	snRNA
RF01557	snRNA
RF01558	snRNA
RF01559	snRNA
RF01560	snRNA
RF01561	snRNA
RF01562	snRNA
RF01563	snRNA
RF01564	snRNA
RF01565	snRNA
RF01566	snRNA
RF01567	snRNA
RF01568	snRNA
RF01569	snRNA
RF01570	snRNA
RF01572	snRNA
RF01573	snRNA
RF01574	snRNA
RF01575	snRNA
RF01576	snRNA
RF01583	snRNA
RF01584	snRNA
RF01585	snRNA
RF01586	snRNA
RF01587	snRNA
RF01588	snRNA
RF01589	snRNA
RF01590	snRNA
RF01591	snRNA
RF01592	snRNA
RF01593	snRNA
RF01594	snRNA
RF01595	snRNA
RF01596	snRNA
RF01597	snRNA
RF01598	snRNA
RF01599	snRNA
RF01600	snRNA
RF01601	snRNA
RF01602	snRNA
RF01603	snRNA
RF01604	snRNA
RF01605	snRNA
RF01606	snRNA
RF01607	snRNA
RF01608	snRNA
RF01609	snRNA
RF01610	snRNA
RF01611	snRNA
RF01612	snRNA
RF01613	snRNA
RF01614	snRNA
RF01615	snRNA
RF01617	snRNA
RF01618	snRNA
RF01620	snRNA
RF01621	snRNA
RF01622	snRNA
RF01624	snRNA
RF01625	snRNA
RF01626	snRNA
RF01627	snRNA
RF01628	snRNA
RF01629	snRNA
RF01630	snRNA
RF01631	snRNA
RF01632	snRNA
RF01633	snRNA
RF01634	snRNA
RF01635	snRNA
RF01636	snRNA
RF01637	snRNA
RF01638	snRNA
RF01639	snRNA
RF01640	snRNA
RF01641	snRNA
RF01642	snRNA
RF01644	snRNA
RF01645	snRNA
RF01646	snRNA
RF01647	snRNA
RF01648	snRNA
RF01649	snRNA
RF01650	snRNA
RF01651	snRNA
RF01652	snRNA
RF01653	snRNA
RF01654	snRNA
RF01655	snRNA
RF01658	snRNA
RF01659	snRNA
RF01660	snRNA
RF01661	snRNA
RF01662	snRNA
RF01664	snRNA
RF01802	snRNA
RF01829	snRNA
RF01844	snRNA
RF01846	snRNA
RF01847	snRNA
RF01848	snRNA
RF01860	snRNA
RF01861	snRNA
RF01862	snRNA
RF01863	snRNA
RF01864	snRNA
RF01866	snRNA
RF02163	snRNA
RF00014	sRNA
RF00018	sRNA
RF00021	sRNA
RF00034	sRNA
RF00035	sRNA
RF00057	sRNA
RF00077	sRNA
RF00078	sRNA
RF00079	sRNA
RF00081	sRNA
RF00082	sRNA
RF00083	sRNA
RF00084	sRNA
RF00101	sRNA
RF00110	sRNA
RF00111	sRNA
RF00112	sRNA
RF00113	sRNA
RF00115	sRNA
RF00116	sRNA
RF00117	sRNA
RF00118	sRNA
RF00119	sRNA
RF00121	sRNA
RF00122	sRNA
RF00124	sRNA
RF00125	sRNA
RF00126	sRNA
RF00128	sRNA
RF00166	sRNA
RF00195	sRNA
RF00368	sRNA
RF00369	sRNA
RF00370	sRNA
RF00371	sRNA
RF00372	sRNA
RF00378	sRNA
RF00444	sRNA
RF00505	sRNA
RF00519	sRNA
RF00615	sRNA
RF00616	sRNA
RF01116	sRNA
RF01385	sRNA
RF01386	sRNA
RF01387	sRNA
RF01388	sRNA
RF01389	sRNA
RF01390	sRNA
RF01391	sRNA
RF01392	sRNA
RF01393	sRNA
RF01394	sRNA
RF01395	sRNA
RF01396	sRNA
RF01397	sRNA
RF01398	sRNA
RF01399	sRNA
RF01400	sRNA
RF01401	sRNA
RF01402	sRNA
RF01403	sRNA
RF01404	sRNA
RF01405	sRNA
RF01406	sRNA
RF01407	sRNA
RF01408	sRNA
RF01409	sRNA
RF01410	sRNA
RF01411	sRNA
RF01412	sRNA
RF01457	sRNA
RF01459	sRNA
RF01460	sRNA
RF01461	sRNA
RF01462	sRNA
RF01463	sRNA
RF01464	sRNA
RF01465	sRNA
RF01466	sRNA
RF01467	sRNA
RF01468	sRNA
RF01469	sRNA
RF01470	sRNA
RF01471	sRNA
RF01472	sRNA
RF01473	sRNA
RF01474	sRNA
RF01476	sRNA
RF01477	sRNA
RF01478	sRNA
RF01479	sRNA
RF01487	sRNA
RF01488	sRNA
RF01489	sRNA
RF01492	sRNA
RF01493	sRNA
RF01494	sRNA
RF01496	sRNA
RF01503	sRNA
RF01504	sRNA
RF01512	sRNA
RF01519	sRNA
RF01520	sRNA
RF01521	sRNA
RF01527	sRNA
RF01528	sRNA
RF01529	sRNA
RF01530	sRNA
RF01571	sRNA
RF01578	sRNA
RF01579	sRNA
RF01580	sRNA
RF01581	sRNA
RF01582	sRNA
RF01619	sRNA
RF01623	sRNA
RF01643	sRNA
RF01656	sRNA
RF01663	sRNA
RF01665	sRNA
RF01668	sRNA
RF01669	sRNA
RF01670	sRNA
RF01671	sRNA
RF01672	sRNA
RF01673	sRNA
RF01674	sRNA
RF01675	sRNA
RF01676	sRNA
RF01677	sRNA
RF01678	sRNA
RF01679	sRNA
RF01680	sRNA
RF01681	sRNA
RF01682	sRNA
RF01683	sRNA
RF01684	sRNA
RF01685	sRNA
RF01686	sRNA
RF01687	sRNA
RF01690	sRNA
RF01691	sRNA
RF01693	sRNA
RF01694	sRNA
RF01696	sRNA
RF01698	sRNA
RF01699	sRNA
RF01700	sRNA
RF01701	sRNA
RF01702	sRNA
RF01703	sRNA
RF01705	sRNA
RF01706	sRNA
RF01710	sRNA
RF01712	sRNA
RF01714	sRNA
RF01718	sRNA
RF01719	sRNA
RF01722	sRNA
RF01723	sRNA
RF01728	sRNA
RF01732	sRNA
RF01742	sRNA
RF01757	sRNA
RF01762	sRNA
RF01775	sRNA
RF01781	sRNA
RF01782	sRNA
RF01783	sRNA
RF01784	sRNA
RF01789	sRNA
RF01791	sRNA
RF01793	sRNA
RF01796	sRNA
RF01808	sRNA
RF01810	sRNA
RF01812	sRNA
RF01814	sRNA
RF01815	sRNA
RF01816	sRNA
RF01817	sRNA
RF01818	sRNA
RF01819	sRNA
RF01820	sRNA
RF01821	sRNA
RF01822	sRNA
RF01823	sRNA
RF01827	sRNA
RF01828	sRNA
RF01858	sRNA
RF01867	sRNA
RF02029	sRNA
RF02030	sRNA
RF02031	sRNA
RF02049	sRNA
RF02050	sRNA
RF02051	sRNA
RF02052	sRNA
RF02053	sRNA
RF02054	sRNA
RF02055	sRNA
RF02056	sRNA
RF02057	sRNA
RF02059	sRNA
RF02060	sRNA
RF02062	sRNA
RF02063	sRNA
RF02064	sRNA
RF02065	sRNA
RF02066	sRNA
RF02067	sRNA
RF02070	sRNA
RF02071	sRNA
RF02072	sRNA
RF02073	sRNA
RF02074	sRNA
RF02075	sRNA
RF02077	sRNA
RF02078	sRNA
RF02079	sRNA
RF02080	sRNA
RF02081	sRNA
RF02082	sRNA
RF02099	sRNA
RF02100	sRNA
RF02151	sRNA
RF02221	sRNA
RF02222	sRNA
RF02223	sRNA
RF02224	sRNA
RF02225	sRNA
RF02226	sRNA
RF02227	sRNA
RF02228	sRNA
RF02230	sRNA
RF02231	sRNA
RF02232	sRNA
RF02233	sRNA
RF02234	sRNA
RF02235	sRNA
RF02236	sRNA
RF02237	sRNA
RF02238	sRNA
RF02239	sRNA
RF02240	sRNA
RF02241	sRNA
RF02242	sRNA
RF02243	sRNA
RF02268	sRNA
RF02269	sRNA
RF00127	sRNA
RF01852	tRNA
RF00005	tRNA
